Learn R Programming

lacrmr (version 1.0.5)

get_account_information: get_account_information

Description

Return your user account information from Less annoying CRM

Usage

get_account_information(user_code, api_token)

Arguments

user_code

The user code to identify your account

api_token

The api token to connect to your account

Details

For using this function you will need to get your credentials from your Less Annoying CRM. Make sure to have your user code and your api_token.

Examples

Run this code
# NOT RUN {
get_account_information(user_code = "6A6E88",
                       api_token = "FBHV7C")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab