Learn R Programming

lacrmr (version 1.0.5)

search_contacts: search_contacts

Description

Return the contacts information from Less annoying CRM.

Usage

search_contacts(user_code, api_token, search_term = "")

Arguments

user_code

The user code to identify your account

api_token

The api token to connect to your account

search_term

The contact name or other term to make an specific call to the API. If you want to search for group enter "Group:GROUP_NAME"

Examples

Run this code
# NOT RUN {
search_contacts(user_code = "6A6E88",
               api_token = "TQ9XM",
               search_term = "brenesii")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab