powered by
Return the contacts information from Less annoying CRM.
search_contacts(user_code, api_token, search_term = "")
The user code to identify your account
The api token to connect to your account
The contact name or other term to make an specific call to the API. If you want to search for group enter "Group:GROUP_NAME"
# NOT RUN { search_contacts(user_code = "6A6E88", api_token = "TQ9XM", search_term = "brenesii") # } # NOT RUN { # }
Run the code above in your browser using DataLab